@@ -11,7 +11,7 @@ from .application import app
 
 
 @app.exception_handler(exceptions.BaseServerException)
-async def exceptionHandler(
+async def exception_handler(
     request: Request,
     exc: exceptions.BaseServerException,
 ) -> Response:
@@ -33,11 +33,11 @@ async def exceptionHandler(
 
 
 @app.exception_handler(StarletteHTTPException)
-async def overrideHandler(
+async def override_handler(
     request: Request,
     exc: StarletteHTTPException,
 ):
-    return await exceptionHandler(
+    return await exception_handler(
         request,
         exceptions.BaseHTTPException(
             exc.detail,
@@ -48,8 +48,8 @@ async def overrideHandler(
 
 
 @app.exception_handler(AssertionError)
-async def assertionHandler(request: Request, exc: AssertionError):
-    return await exceptionHandler(
+async def assertion_handler(request: Request, exc: AssertionError):
+    return await exception_handler(
         request,
         exceptions.ClientSideException(detail=f"Assertion: {exc}"),
     )
@@ -57,8 +57,8 @@ async def assertionHandler(request: Request, exc: AssertionError):
 
 @app.exception_handler(FastAPIValidationError)
 @app.exception_handler(PydanticValidationError)
-async def validationHandler(request: Request, exc: PydanticValidationError):
-    return await exceptionHandler(
+async def validation_handler(request: Request, exc: PydanticValidationError):
+    return await exception_handler(
         request,
         exceptions.ValidationException(detail=str(exc), validation=exc.errors()),
     )
