@@ -13,7 +13,7 @@ from hibiapi.utils.log import logger
 from hibiapi.utils.routing import request_headers, response_headers
 
 from .application import app
-from .handlers import exceptionHandler
+from .handlers import exception_handler
 
 if Config["server"]["gzip"].as_bool():
     app.add_middleware(GZipMiddleware)
@@ -75,7 +75,7 @@ async def uncaught_exception_handler(
     try:
         response = await call_next(request)
     except Exception as error:
-        response = await exceptionHandler(
+        response = await exception_handler(
             request, exc=UncaughtException.with_exception(error)
         )
     return response
