@@ -1,6 +1,7 @@
 from typing import Optional
 
 from fastapi import Depends, File, Form
+from loguru import logger
 
 from hibiapi.api.sauce import (
     DeduplicateType,
@@ -12,13 +13,17 @@ from hibiapi.api.sauce import (
 )
 from hibiapi.utils.routing import SlashRouter
 
+if not SauceConstants.API_KEY.strip():
+    logger.warning("Sauce API key not set, SauceNAO endpoint will be unavailable")
+    SauceConstants.CONFIG["enabled"].set(False)
+
 __mount__, __config__ = "sauce", SauceConstants.CONFIG
 router = SlashRouter(tags=["SauceNAO"])
 
 SauceAPIRoot = NetRequest()
 
 
-async def requestClient():
+async def request_client():
     async with SauceAPIRoot as client:
         yield SauceEndpoint(client)
 
@@ -31,7 +36,7 @@ async def sauce_url(
     database: Optional[int] = None,
     enabled_mask: Optional[int] = None,
     disabled_mask: Optional[int] = None,
-    endpoint: SauceEndpoint = Depends(requestClient),
+    endpoint: SauceEndpoint = Depends(request_client),
 ):
     """
     ## Name: `sauce_url`
@@ -77,7 +82,7 @@ async def sauce_form(
     database: Optional[int] = Form(None),
     enabled_mask: Optional[int] = Form(None),
     disabled_mask: Optional[int] = Form(None),
-    endpoint: SauceEndpoint = Depends(requestClient),
+    endpoint: SauceEndpoint = Depends(request_client),
 ):
     """
     ## Name: `sauce_form`
